﻿' **********************************************
' TSND121に計測開始/停止を送るだけの簡単なサンプルPG(Visual BASIC)
'
' 1.予めSensorController等で，センサを計測開始/停止に反応するように
' 　設定しておく必要があります．
'
' 2.実行前に，TSNDComPortを適切なポート番号に変更して下さい
'
' 本プログラムは，シリアルポートを使用してバイナリコマンドを送信する
' 簡単なサンプルプログラムです．本来は，実行したコマンドのレスポンス
' を確認してエラーの有無をチェックしたり，受信データをハンドリングする
' 処理部が必要になります（マルチスレッドで実行することが望ましい）
' 
'
' Copyright (C) 2013  ATR-Promotinos, Inc.
'
' 2013/01/10 T.Adachi
' **********************************************

Imports System
Imports System.IO.Ports
Imports System.Text

Public Class VBSampleForm

    Private Const TSNDComPort As String = "COM33"  ' TSND121の接続されているポート

    ' 起動時初期化用
    Private Sub VBSampleForm_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

    End Sub

    ' 終了処理用
    Private Sub VBSampleForm_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs) Handles MyBase.FormClosed
        If SerialPort1.IsOpen Then
            SerialPort1.Close()
        End If
    End Sub


    ' 接続して計測開始
    Private Sub StartButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles StartButton.Click

        If SerialPort1.IsOpen = True Then
            ' 既に開いていたらシリアルポートをクローズ
            SerialPort1.Close()
        End If

        ' シリアルポート設定
        SerialPort1.PortName = TSNDComPort
        SerialPort1.BaudRate = 115200
        SerialPort1.DataBits = 8
        SerialPort1.Parity = Parity.None
        SerialPort1.StopBits = StopBits.One
        SerialPort1.Handshake = Handshake.RequestToSend

        Try
            ' ポートオープン
            SerialPort1.Open()

            ' 計測開始コマンド送信
            Dim startCommand As Byte() = New Byte() {&H9A, &H13, &H0, &H0, &H1, &H1, &H0, &H0, &H0, &H0, &H0, &H1, &H1, &H0, &H0, &H0, &H89}

            SerialPort1.Write(startCommand, 0, startCommand.Length)

        Catch ex As Exception
            MsgBox(ex.Message)
        End Try
    End Sub

    ' 接続して計測停止
    Private Sub StopButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles StopButton.Click
        If SerialPort1.IsOpen = True Then
            ' 既に開いていたらシリアルポートをクローズ
            SerialPort1.Close()
        End If

        ' シリアルポート設定
        SerialPort1.PortName = TSNDComPort
        SerialPort1.BaudRate = 115200
        SerialPort1.DataBits = 8
        SerialPort1.Parity = Parity.None
        SerialPort1.StopBits = StopBits.One
        SerialPort1.Handshake = Handshake.RequestToSend

        Try
            ' ポートオープン
            SerialPort1.Open()

            ' 計測停止コマンド送信
            Dim stopCommand As Byte() = New Byte() {&H9A, &H15, &H0, &H8F}

            SerialPort1.Write(stopCommand, 0, stopCommand.Length)

        Catch ex As Exception
            MsgBox(ex.Message)
        End Try

    End Sub

End Class
